abacusai.vector_store — AbacusAI documentation

# `abacusai.vector_store`

## Module Contents

### Classes

`VectorStore` | A vector store that stores embeddings for a list of document trunks.

class abacusai.vector_store.VectorStore(client, vectorStoreId=None, createdAt=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A vector store that stores embeddings for a list of document trunks.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - vectorStoreId (str) – The unique identifier of the vector store.

    - createdAt (str) – When the vector store was created.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict